@@ -236,6 +236,8 @@ class KeyboardEvent(InputEvent):
             self.modifiers |= (1 << pyatspi.MODIFIER_NUMLOCK)
         self.event_string = event.event_string
         self.keyval_name = Gdk.keyval_name(event.id)
+        if self.event_string  == "":
+            self.event_string = self.keyval_name
         self.timestamp = event.timestamp
         self.is_duplicate = self in [orca_state.lastInputEvent,
                                      orca_state.lastNonModifierKeyEvent]
@@ -325,7 +327,7 @@ class KeyboardEvent(InputEvent):
         elif self.isModifierKey():
             self.keyType = KeyboardEvent.TYPE_MODIFIER
             self.shouldEcho = _mayEcho and settings.enableModifierKeys
-            if self.isOrcaModifier():
+            if self.isOrcaModifier() and not self.is_duplicate:
                 now = time.time()
                 if KeyboardEvent.lastOrcaModifierAlone:
                     if _isPressed:
@@ -919,6 +921,7 @@ class KeyboardEvent(InputEvent):
         if orca_state.bypassNextCommand:
             if not self.isModifierKey():
                 orca_state.bypassNextCommand = False
+            self._script.addKeyGrabs()
             return False, 'Bypass next command'
 
         if not self._should_consume:
@@ -939,10 +942,10 @@ class KeyboardEvent(InputEvent):
                 try:
                     if modifiers & modifier:
                         lock = pyatspi.KEY_UNLOCKMODIFIERS
-                        debug.println(debug.LEVEL_INFO, "Locking capslock", True)
+                        debug.println(debug.LEVEL_INFO, "Unlocking capslock", True)
                     else:
                         lock = pyatspi.KEY_LOCKMODIFIERS
-                        debug.println(debug.LEVEL_INFO, "Unlocking capslock", True)
+                        debug.println(debug.LEVEL_INFO, "Locking capslock", True)
                     pyatspi.Registry.generateKeyboardEvent(modifier, None, lock)
                     debug.println(debug.LEVEL_INFO, "Done with capslock", True)
                 except:
