@@ -562,11 +562,7 @@ class Utilities(script_utilities.Utilities):
         Returns a (title, position, count) tuple.
         """
 
-        if self.isDocument(obj):
-            dv = obj
-        else:
-            dv = self.getContainingDocument(obj)
-
+        dv = self.getDocumentForObject(obj)
         if not dv or not self.isDrawingView(dv):
             return "", 0, 0
 
@@ -744,6 +740,9 @@ class Utilities(script_utilities.Utilities):
 
         return obj, 0
 
+    def getWordAtOffsetAdjustedForNavigation(self, obj, offset=None):
+        return self.getWordAtOffset(obj, offset)
+
     def shouldReadFullRow(self, obj):
         if self._script._lastCommandWasStructNav:
             return False
@@ -752,10 +751,7 @@ class Utilities(script_utilities.Utilities):
         if lastKey in ["Tab", "ISO_Left_Tab"]:
             return False
 
-        if not super().shouldReadFullRow(obj):
-            return False
-
-        return self.cellRowChanged(obj)
+        return super().shouldReadFullRow(obj)
 
     def presentEventFromNonShowingObject(self, event):
         return self.inDocumentContent(event.source)
