@@ -27,7 +27,6 @@ __license__   = "LGPL"
 from orca import debug
 from orca import orca
 from orca import orca_state
-from orca import speech
 from orca.scripts import default
 
 from .braille_generator import BrailleGenerator
@@ -82,6 +81,8 @@ class Script(default.Script):
         """Callback for object:text-changed:insert accessibility events."""
 
         if not self.utilities.treatEventAsCommand(event):
+            msg = "TERMINAL: Passing along event to default script."
+            debug.println(debug.LEVEL_INFO, msg, True)
             super().onTextInserted(event)
             return
 
@@ -94,8 +95,8 @@ class Script(default.Script):
         if len(newString) == 1:
             self.speakCharacter(newString)
         else:
-            voice = self.speechGenerator.voice(string=newString)
-            speech.speak(newString, voice)
+            voice = self.speechGenerator.voice(obj=event.source, string=newString)
+            self.speakMessage(newString, voice=voice)
 
         if self.flatReviewContext:
             return
@@ -136,9 +137,7 @@ class Script(default.Script):
 
         msg = "TERMINAL: Presenting keyboard event %s" % string
         debug.println(debug.LEVEL_INFO, msg, True)
-
-        voice = self.speechGenerator.voice(string=string)
-        speech.speakKeyEvent(event, voice)
+        self.speakKeyEvent(event)
         return True
 
     def skipObjectEvent(self, event):
@@ -150,7 +149,7 @@ class Script(default.Script):
             if self.utilities.isBackSpaceCommandTextDeletionEvent(event):
                 return False
 
-            newEvent, newTime = self.eventCache.get("object:text-changed:insert")
+            newEvent, newTime = self.eventCache.get("object:text-changed:insert", [None, 0])
 
         if newEvent is None or newEvent.source != event.source:
             return super().skipObjectEvent(event)
